@@ -1,7 +1,9 @@
+*-----------------------------------------------------------------------
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       PROGRAM SGFONZ
 
-      CHARACTER CH*3,CSGI*1,CTTL*32
+      CHARACTER CH*3,USGI*3,CTTL*32
 
       DATA      CTTL/'FONT NO. = #'/
 
@@ -40,7 +42,7 @@
           UX=I/16+0.5
           UY=16-MOD(I,16)-0.5
           IF (.NOT.(I.EQ.30 .OR. I.EQ.31)) THEN
-            CALL SGTXZU( UX, UY, CSGI(I), 0.035, 0, 0, 3 )
+            CALL SGTXZU( UX, UY, USGI(I), 0.035, 0, 0, 3 )
           END IF
           UX=UX+0.48
           UY=UY+0.38
