@@ -10,7 +10,7 @@
       CALL SGLSET('LFULL', .TRUE.)
       CALL SLMGN(0., 0., 0.08, 0.08)
 
-      CALL SLRAT(1., 0.6)                              ! <-- Ĳ
+      CALL SLRAT(1., 0.6)                              ! <-- 縦横比を指定
       CALL SLSTTL('FIGURE TITLE',  'T',  0., -1., 0.02, 1)
       CALL SLSTTL('page:#PAGE',    'B',  1.,  1., 0.02, 2)
       CALL SLSTTL('PROG.NAME',     'B', -1.,  1., 0.02, 3)
