@@ -8,7 +8,7 @@
       CHARACTER FONTNAME*50, CH*3, OPT*20, FULLNAME*70
       INTEGER PM, J, NFNT
 
-      CALL SWLSET('SYSFONT', .TRUE.)
+      CALL SWLSET('LSYSFNT', .TRUE.)
 
       CALL SWFTNM(NFNT)
 
