@@ -20,7 +20,7 @@
       CHARACTER CNOPN*26
 
       INTEGER IDMPDGT
-      LOGICAL LSTDOUT
+      LOGICAL LSTDOT
 
       REAL      RLWFACT
 
@@ -56,15 +56,13 @@
       IF (IWS.EQ.1 .OR. IWS.EQ.2) THEN
         CALL SWIGET('IWIDTH ', IWIDTH)
         CALL SWIGET('IHEIGHT', IHEIGH)
+        CALL SWIGET('ICLRMAP', ICLRMP)
         CALL SWLGET('LFGBG  ', LFGBG )
         CALL SWCGET('FNAME  ', COUT  )
         CALL SWCGET('TITLE  ', CTTL  )
         CALL SWIGET('IDMPDGT ', IDMPDGT)
         CALL SWIGET('IBGPAGE ',IBGPAGE)
-        CALL SWIGET('ICLRMAP', ICLRMP)
         CALL SWCMLL
-        CALL SWQCMF(ICLRMP   , CLRMAP)
-        CALL SWCSET('CLRMAP' , CLRMAP)
         CALL SWQFNM('CLRMAP ', CLRMAP)
         CALL GLCGET('DSPATH',  DSPATH)
 
@@ -127,12 +125,13 @@
      +       LFGBG,LSEP,IFL,CIMGFMT, RIMGCMP, CLRMAP, CBTMAP, COUT,
      +       CTTL)
 
-
         IF (CLRMAP.EQ.(DSPATH(1:LENC(DSPATH))//'colormap.x11')) THEN
           CALL SWQCMF(ICLRMP,CMAP)
           CALL SWCSET('CLRMAP ',CMAP)
         END IF
 
+
+
       LOPEN = .TRUE.
 
       RETURN
@@ -569,8 +568,6 @@
         CALL ZGRSET('shift ',LENZ('shift'), SHIFT)
       END IF
       CALL ZGTXT(WX,WY,QSIZEXRATE,CHARS,NCZ,IROTA,ICENTZ)
-      CALL ZGRCLP()
-   
       RETURN
 
       END
