@@ -1,5 +1,5 @@
 **-----------------------------------------------------------------------
-*     Copyright (C) 2000-2004 GFD Dennou Club. All rights reserved.
+*     Copyright (C) 2000-2016 GFD Dennou Club. All rights reserved.
 *-----------------------------------------------------------------------
       SUBROUTINE SWQFNM(CPARA,CFNAME)
 
@@ -8,12 +8,11 @@
       PARAMETER (MAXP=3,MAXF=3)
 
       LOGICAL   LCHREQ
-      CHARACTER CPLIST(MAXP)*80,CFLIST(MAXF)*80,CPX*80,CX11*4,CPSX*4,
-     +          CMSG*80
+      CHARACTER CPLIST(MAXP)*1024,CFLIST(MAXF)*1024,CPX*1024,
+     +          CX11*4,CPSX*4,CMSG*1024
 
       EXTERNAL  LENC,LCHREQ
 
-
       CPLIST(1)=' '
       CALL GLCGET('DUPATH',CPLIST(2))
       CALL GLCGET('DSPATH',CPLIST(3))
@@ -49,7 +48,6 @@
         CMSG='PARAMETER NAME <'//CPARA(1:LENC(CPARA))//'> IS INVALID.'
         CALL MSGDMP('E','SWQFNM',CMSG)
       END IF
-
       CALL CFSRCH(CPLIST,NP,CFLIST,NF,CFNAME)
 
       END
